==> percona-xtrabackup-8.3.0-1.tar.gz: percona-xtrabackup-8.3.0-1/libs/mysql/binlog/event/compression/factory.h <==
/* Copyright (c) 2019, 2023, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

#ifndef MYSQL_BINLOG_EVENT_COMPRESSION_FACTORY_H
#define MYSQL_BINLOG_EVENT_COMPRESSION_FACTORY_H

#include <memory>
#include "mysql/binlog/event/compression/compressor.h"
#include "mysql/binlog/event/compression/decompressor.h"
#include "mysql/binlog/event/resource/memory_resource.h"  // Memory_resource

namespace mysql::binlog::event::compression {

class Factory {
  using Memory_resource_t = mysql::binlog::event::resource::Memory_resource;

 public:
  static std::unique_ptr<Compressor> build_compressor(
      type t, const Memory_resource_t &memory_resource = Memory_resource_t());
  static std::unique_ptr<Decompressor> build_decompressor(
      type t, const Memory_resource_t &memory_resource = Memory_resource_t());
};

}  // namespace mysql::binlog::event::compression

#endif  // MYSQL_BINLOG_EVENT_COMPRESSION_FACTORY_H

==> percona-xtrabackup_8.4.0-5.orig.tar.gz: percona-xtrabackup-8.4.0-5/libs/mysql/binlog/event/compression/factory.h <==
/* Copyright (c) 2019, 2024, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have either included with
   the program or referenced in the documentation.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

#ifndef MYSQL_BINLOG_EVENT_COMPRESSION_FACTORY_H
#define MYSQL_BINLOG_EVENT_COMPRESSION_FACTORY_H

#include <memory>
#include "mysql/binlog/event/compression/compressor.h"
#include "mysql/binlog/event/compression/decompressor.h"
#include "mysql/binlog/event/resource/memory_resource.h"  // Memory_resource

namespace mysql::binlog::event::compression {

class Factory {
  using Memory_resource_t = mysql::binlog::event::resource::Memory_resource;

 public:
  static std::unique_ptr<Compressor> build_compressor(
      type t, const Memory_resource_t &memory_resource = Memory_resource_t());
  static std::unique_ptr<Decompressor> build_decompressor(
      type t, const Memory_resource_t &memory_resource = Memory_resource_t());
};

}  // namespace mysql::binlog::event::compression

#endif  // MYSQL_BINLOG_EVENT_COMPRESSION_FACTORY_H
